<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About KeePassX</source>
        <translation>O KeePassX</translation>
    </message>
    <message>
        <source>KeePassX is distributed under the term of the GNU General Public License (GPL) version 2 or (at your option) version 3.</source>
        <translation>KeePassX je šířeno za podmínek licence GNU General Public License (GPL) verze 2 a (případně) 3.</translation>
    </message>
    <message>
        <source>Revision</source>
        <translation>Revize</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>S použitím:</translation>
    </message>
</context>
<context>
    <name>AutoType</name>
    <message>
        <source>Auto-Type - KeePassX</source>
        <translation>Automatické vyplňování – KeePassX</translation>
    </message>
    <message>
        <source>Couldn&apos;t find an entry that matches the window title:</source>
        <translation>Nedaří se nalézt položku, která by se shodovala s titulkem okna:</translation>
    </message>
</context>
<context>
    <name>AutoTypeAssociationsModel</name>
    <message>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <source>Sequence</source>
        <translation>Posloupnost</translation>
    </message>
    <message>
        <source>Default sequence</source>
        <translation>Výchozí posloupnost</translation>
    </message>
</context>
<context>
    <name>AutoTypeSelectDialog</name>
    <message>
        <source>Auto-Type - KeePassX</source>
        <translation>Automatické vyplňování – KeePassX</translation>
    </message>
    <message>
        <source>Select entry to Auto-Type:</source>
        <translation>Vyberte položku, kterou se bude automaticky vyplňovat:</translation>
    </message>
</context>
<context>
    <name>ChangeMasterKeyWidget</name>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Enter password:</source>
        <translation>Zadejte heslo:</translation>
    </message>
    <message>
        <source>Repeat password:</source>
        <translation>Zopakujte heslo:</translation>
    </message>
    <message>
        <source>Key file</source>
        <translation>Soubor s klíčem</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Procházet</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Vytvořit</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>Soubory s klíči</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Veškeré soubory</translation>
    </message>
    <message>
        <source>Create Key File...</source>
        <translation>Vytvořit soubor s klíčem…</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Unable to create Key File : </source>
        <translation>Nedaří se vytvořit soubor s klíčem:</translation>
    </message>
    <message>
        <source>Select a key file</source>
        <translation>Vyberte soubor s klíčem</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Dotaz</translation>
    </message>
    <message>
        <source>Do you really want to use an empty string as password?</source>
        <translation>Opravdu chcete ponechat bez hesla, tedy nechráněné?</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>Nepodařilo se vám zadat heslo do obou kolonek stejně.</translation>
    </message>
    <message>
        <source>Failed to set key file</source>
        <translation>Nezdařilo se nastavit soubor s klíčem</translation>
    </message>
    <message>
        <source>Failed to set %1 as the Key file:
%2</source>
        <translation>Nezdařilo se nastavit %1 jako soubor s klíčem:
%2</translation>
    </message>
</context>
<context>
    <name>DatabaseOpenWidget</name>
    <message>
        <source>Enter master key</source>
        <translation>Zadejte hlavní klíč</translation>
    </message>
    <message>
        <source>Key File:</source>
        <translation>Soubor s klíčem:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Procházet</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Databázi se nedaří otevřít.</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>Soubor s klíčem se nedaří otevřít</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Veškeré soubory</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>Soubory s klíči</translation>
    </message>
    <message>
        <source>Select key file</source>
        <translation>Vyberte soubor s klíčem</translation>
    </message>
</context>
<context>
    <name>DatabaseRepairWidget</name>
    <message>
        <source>Repair database</source>
        <translation>Opravit databázi</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>Nedaří se otevřít soubor s klíčem</translation>
    </message>
    <message>
        <source>Database opened fine. Nothing to do.</source>
        <translation>Databáze je v pořádku otevřená. Není třeba žádného zásahu.</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Nedaří se otevřít databázi.</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Úspěch</translation>
    </message>
    <message>
        <source>The database has been successfully repaired
You can now save it.</source>
        <translation>Databáze je úspěšně opravená
Nyní jí můžete uložit.</translation>
    </message>
    <message>
        <source>Unable to repair the database.</source>
        <translation>Databázi se nedaří opravit.</translation>
    </message>
</context>
<context>
    <name>DatabaseSettingsWidget</name>
    <message>
        <source>Database name:</source>
        <translation>Název databáze:</translation>
    </message>
    <message>
        <source>Database description:</source>
        <translation>Popis databáze:</translation>
    </message>
    <message>
        <source>Transform rounds:</source>
        <translation>Počet průchodů šifrovacího algoritmu:</translation>
    </message>
    <message>
        <source>Default username:</source>
        <translation>Výchozí uživatelské jméno:</translation>
    </message>
    <message>
        <source>Use recycle bin:</source>
        <translation>Namísto mazání přesouvat do Koše:</translation>
    </message>
    <message>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <source>Benchmark</source>
        <translation>Test výkonu</translation>
    </message>
    <message>
        <source>Max. history items:</source>
        <translation>Omezit počet uchovávaných předchozích verzí položky na:</translation>
    </message>
    <message>
        <source>Max. history size:</source>
        <translation>Omezit datový objem předchozích verzí položek na:</translation>
    </message>
</context>
<context>
    <name>DatabaseTabWidget</name>
    <message>
        <source>Root</source>
        <translation>Kořen</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>Databáze ve formátu KeePass verze 2</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Veškeré soubory</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>Otevřít databázi</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <source>File not found!</source>
        <translation>Soubor nebyl nalezen!</translation>
    </message>
    <message>
        <source>Open KeePass 1 database</source>
        <translation>Otevřít databázi ve formátu KeePass verze 1</translation>
    </message>
    <message>
        <source>KeePass 1 database</source>
        <translation>Databáze ve formátu KeePass verze 1</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Veškeré soubory (*)</translation>
    </message>
    <message>
        <source>Close?</source>
        <translation>Zavřít?</translation>
    </message>
    <message>
        <source>Save changes?</source>
        <translation>Uložit změny?</translation>
    </message>
    <message>
        <source>&quot;%1&quot; was modified.
Save changes?</source>
        <translation>„%1“ bylo změněno.
Uložit změny?</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>Zápis do databáze se nezdařil.</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>Uložit databázi jako</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>Nová databáze</translation>
    </message>
    <message>
        <source>locked</source>
        <translation>zamčeno</translation>
    </message>
    <message>
        <source>The database you are trying to open is locked by another instance of KeePassX.
Do you want to open it anyway? Alternatively the database is opened read-only.</source>
        <translation>Pro databázi, kterou se pokoušíte otevřít, existuje zámek úprav (stejnojmenný 
.lock soubor). To znamená, že je nejspíš už otevřená v jiném okně KeePassX 
(v případě sdíleného úložiště, třeba i na jiném počítači). Pokud tomu tak není, 
je zámek nejspíš pozůstatkem předchozího neočekávaného ukončení aplikace 
a je možné ho smazat. V každém případě, dotčenou databázi je možné otevřít
 i tak, ale pouze pro čtení. Chcete?</translation>
    </message>
    <message>
        <source>Lock database</source>
        <translation>Uzamknout databázi</translation>
    </message>
    <message>
        <source>Can't lock the database as you are currently editing it.
Please press cancel to finish your changes or discard them.</source>
        <translation>Nelze uzamknout databázi, protože ji v tuto chvíli upravujete.
Pokud chcete změny dokončit, klikněte na Zrušit. V opačném případě změny zahodíte.</translation>
    </message>
    <message>
        <source>This database has never been saved.
You can save the database or stop locking it.</source>
        <translation>Tato databáze doposud ještě nebyla uložena.
Buď ji můžete uložit, nebo neuzamknout.</translation>
    </message>
    <message>
        <source>This database has been modified.
Do you want to save the database before locking it?
Otherwise your changes are lost.</source>
        <translation>Tato databáze byla upravena.
Chcete ji před uzamčením uložit?
Pokud ne, provedené změny budou ztraceny.</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is in edit mode.
Discard changes and close anyway?</source>
        <translation>„%1“ je právě upravováno.
Přesto zavřít a zahodit změny?</translation>
    </message>
    <message>
        <source>Export database to CSV file</source>
        <translation>Exportovat databázi do CSV souboru</translation>
    </message>
    <message>
        <source>CSV file</source>
        <translation>CSV soubor</translation>
    </message>
    <message>
        <source>Writing the CSV file failed.</source>
        <translation>Zápis do CSV souboru se nezdařil.</translation>
    </message>
    <message>
        <source>The database you are trying to save as is locked by another instance of KeePassX.
Do you want to save it anyway?</source>
        <translation>Databáze, kterou se pokoušíte uložit, je uzamčena jinou instancí KeePassX.
Přesto uložit?</translation>
    </message>
</context>
<context>
    <name>DatabaseWidget</name>
    <message>
        <source>Change master key</source>
        <translation>Změnit hlavní klíč</translation>
    </message>
    <message>
        <source>Delete entry?</source>
        <translation>Smazat položku?</translation>
    </message>
    <message>
        <source>Do you really want to delete the entry &quot;%1&quot; for good?</source>
        <translation>Opravdu chcete nenávratně smazat položku „%1“?</translation>
    </message>
    <message>
        <source>Delete entries?</source>
        <translation>Smazat položky?</translation>
    </message>
    <message>
        <source>Do you really want to delete %1 entries for good?</source>
        <translation>Opravdu chcete nenávratně smazat %1 položek?</translation>
    </message>
    <message>
        <source>Move entries to recycle bin?</source>
        <translation>Přesunout položky do Koše?</translation>
    </message>
    <message numerus="yes">
        <source>Do you really want to move %n entry(s) to the recycle bin?</source>
        <translation><numerusform>Opravdu chcete přesunout %n položku do Koše?</numerusform><numerusform>Opravdu chcete přesunout %n položky do Koše?</numerusform><numerusform>Opravdu chcete přesunout %n položek do Koše?</numerusform></translation>
    </message>
    <message>
        <source>Delete group?</source>
        <translation>Smazat skupinu?</translation>
    </message>
    <message>
        <source>Do you really want to delete the group &quot;%1&quot; for good?</source>
        <translation>Opravdu chcete nenávratně smazat skupinu „%1“?</translation>
    </message>
    <message>
        <source>Current group</source>
        <translation>Stávající skupina</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Nedaří se spočítat hlavní klíč</translation>
    </message>
</context>
<context>
    <name>EditEntryWidget</name>
    <message>
        <source>Entry</source>
        <translation>Položka</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Pokročilé</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>Ikona</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>Automatické vyplňování</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Vlastnosti</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <source>Entry history</source>
        <translation>Historie položky</translation>
    </message>
    <message>
        <source>Add entry</source>
        <translation>Přidat položku</translation>
    </message>
    <message>
        <source>Edit entry</source>
        <translation>Upravit položku</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>Zadání hesla se neshodují.</translation>
    </message>
    <message>
        <source>New attribute</source>
        <translation>Nový atribut</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>Vyberte soubor</translation>
    </message>
    <message>
        <source>Unable to open file</source>
        <translation>Soubor se nedaří otevřít</translation>
    </message>
    <message>
        <source>Save attachment</source>
        <translation>Uložit přílohu</translation>
    </message>
    <message>
        <source>Unable to save the attachment:
</source>
        <translation>Přílohu se nedaří uložit:
</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Zítra</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation><numerusform>%n týden</numerusform><numerusform>%n týdny</numerusform><numerusform>%n týdnů</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s)</source>
        <translation><numerusform>%n měsíc</numerusform><numerusform>%n měsíce</numerusform><numerusform>%n měsíců</numerusform></translation>
    </message>
    <message>
        <source>1 year</source>
        <translation>1 rok</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAdvanced</name>
    <message>
        <source>Additional attributes</source>
        <translation>Další atributy</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odebrat</translation>
    </message>
    <message>
        <source>Attachments</source>
        <translation>Přílohy</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAutoType</name>
    <message>
        <source>Enable Auto-Type for this entry</source>
        <translation>Zapnout automatické vyplňování této položky</translation>
    </message>
    <message>
        <source>Inherit default Auto-Type sequence from the group</source>
        <translation>Převzít výchozí posloupnost automatického vyplňování od skupiny</translation>
    </message>
    <message>
        <source>Use custom Auto-Type sequence:</source>
        <translation>Použít vlastní posloupnost automatického vyplňování:</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Window title:</source>
        <translation>Titulek okna:</translation>
    </message>
    <message>
        <source>Use default sequence</source>
        <translation>Použít výchozí posloupnost</translation>
    </message>
    <message>
        <source>Set custom sequence:</source>
        <translation>Nastavit vlastní posloupnost:</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetHistory</name>
    <message>
        <source>Show</source>
        <translation>Zobrazit</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Obnovit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Delete all</source>
        <translation>Smazat vše</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetMain</name>
    <message>
        <source>Title:</source>
        <translation>Titulek:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Uživatelské jméno:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>Zopakování hesla:</translation>
    </message>
    <message>
        <source>Gen.</source>
        <translation>Tvoř</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL adresa:</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Platnost skončí:</translation>
    </message>
    <message>
        <source>Presets</source>
        <translation>Předpřipravené</translation>
    </message>
    <message>
        <source>Notes:</source>
        <translation>Poznámky:</translation>
    </message>
</context>
<context>
    <name>EditGroupWidget</name>
    <message>
        <source>Group</source>
        <translation>Skupina</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>Ikona</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Vlastnosti</translation>
    </message>
    <message>
        <source>Add group</source>
        <translation>Přidat skupinu</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>Upravit skupinu</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Zapnout</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Vypnout</translation>
    </message>
    <message>
        <source>Inherit from parent group (%1)</source>
        <translation>Převzít od nadřazené skupiny (%1)</translation>
    </message>
</context>
<context>
    <name>EditGroupWidgetMain</name>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>Poznámky</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Platnost skončí</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>Auto-type</source>
        <translation>Automatické vyplňování</translation>
    </message>
    <message>
        <source>Use default auto-type sequence of parent group</source>
        <translation>Použít výchozí posloupnost automatického vyplňování z nadřazené skupiny</translation>
    </message>
    <message>
        <source>Set default auto-type sequence</source>
        <translation>Nastavit výchozí posloupnost automatického vyplňování</translation>
    </message>
</context>
<context>
    <name>EditWidgetIcons</name>
    <message>
        <source>Use default icon</source>
        <translation>Použít výchozí ikonu</translation>
    </message>
    <message>
        <source>Use custom icon</source>
        <translation>Použít svou vlastní ikonu</translation>
    </message>
    <message>
        <source>Add custom icon</source>
        <translation>Přidat svou vlastní ikonu</translation>
    </message>
    <message>
        <source>Delete custom icon</source>
        <translation>Smazat svou vlastní ikonu</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Veškeré soubory</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>Vyberte obrázek</translation>
    </message>
    <message>
        <source>Can&apos;t delete icon!</source>
        <translation>Ikonu nelze smazat!</translation>
    </message>
    <message numerus="yes">
        <source>Can&apos;t delete icon. Still used by %n item(s).</source>
        <translation><numerusform>Ikonu není možné smazat. Je používána %n položkou.</numerusform><numerusform>Ikonu není možné smazat. Je používána %n položkami.</numerusform><numerusform>Ikonu není možné smazat. Ještě jí používá %n položek.</numerusform></translation>
    </message>
</context>
<context>
    <name>EditWidgetProperties</name>
    <message>
        <source>Created:</source>
        <translation>Okamžik vytvoření:</translation>
    </message>
    <message>
        <source>Modified:</source>
        <translation>Okamžik minulé úpravy:</translation>
    </message>
    <message>
        <source>Accessed:</source>
        <translation>Okamžik minulého přístupu:</translation>
    </message>
    <message>
        <source>Uuid:</source>
        <translation>Univerzálně jedinečný identifikátor:</translation>
    </message>
</context>
<context>
    <name>EntryAttributesModel</name>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
</context>
<context>
    <name>EntryHistoryModel</name>
    <message>
        <source>Last modified</source>
        <translation>Okamžik minulé změny</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titulek</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uživatelské jméno</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL adresa</translation>
    </message>
</context>
<context>
    <name>EntryModel</name>
    <message>
        <source>Group</source>
        <translation>Skupina</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titulek</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uživatelské jméno</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL adresa</translation>
    </message>
</context>
<context>
    <name>Group</name>
    <message>
        <source>Recycle Bin</source>
        <translation>Koš</translation>
    </message>
</context>
<context>
    <name>KeePass1OpenWidget</name>
    <message>
        <source>Import KeePass1 database</source>
        <translation>Importovat databázi ve formátu KeePass verze 1</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Databázi se nedaří otevřít.</translation>
    </message>
</context>
<context>
    <name>KeePass1Reader</name>
    <message>
        <source>Unable to read keyfile.</source>
        <translation>Nedaří se načíst soubor s klíčem.</translation>
    </message>
    <message>
        <source>Not a KeePass database.</source>
        <translation>Nejedná se o databázi Keepass.</translation>
    </message>
    <message>
        <source>Unsupported encryption algorithm.</source>
        <translation>Nepodporovaný šifrovací algoritmus.</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>Nepodporovaná verze databáze KeePass.</translation>
    </message>
    <message>
        <source>Root</source>
        <translation>Kořen</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Nedaří se spočítat hlavní klíč</translation>
    </message>
</context>
<context>
    <name>KeePass2Reader</name>
    <message>
        <source>Not a KeePass database.</source>
        <translation>Nejedná se o databázi KeePass.</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>Nepodporovaná verze databáze KeePass.</translation>
    </message>
    <message>
        <source>Wrong key or database file is corrupt.</source>
        <translation>Chybný klíč nebo je databáze poškozená.</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Nedaří se spočítat hlavní klíč</translation>
    </message>
    <message>
        <source>The selected file is an old KeePass 1 database (.kdb).

You can import it by clicking on Database &gt; 'Import KeePass 1 database'.
This is a one-way migration. You won&apos;t be able to open the imported database with the old KeePassX 0.4 version.</source>
        <translation>Zvolený soubor je databáze ve starém formátu KeePass 1 (.kdb).

Můžete ho importovat pomocí Databáze → Importovat databázi KeePass 1.
Jedná se o jednosměrný převod. Databázi, vzniklou z importu, nepůjde otevřít ve staré verzi KeePassX 0.4.</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Fatal error while testing the cryptographic functions.</source>
        <translation>Při ověřování šifrovacích funkcí byl zjištěn fatální nedostatek.</translation>
    </message>
    <message>
        <source>KeePassX - Error</source>
        <translation>KeePassX – chyba</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Database</source>
        <translation>Databáze</translation>
    </message>
    <message>
        <source>Recent databases</source>
        <translation>Nedávno otevřené databáze</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>Entries</source>
        <translation>Položky</translation>
    </message>
    <message>
        <source>Copy attribute to clipboard</source>
        <translation>Zkopírovat atribut do schránky</translation>
    </message>
    <message>
        <source>Groups</source>
        <translation>Skupiny</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Zobrazit</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Ukončit aplikaci</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O aplikaci</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>Otevřít databázi</translation>
    </message>
    <message>
        <source>Save database</source>
        <translation>Uložit databázi</translation>
    </message>
    <message>
        <source>Close database</source>
        <translation>Zavřít databázi</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>Nová databáze</translation>
    </message>
    <message>
        <source>Add new entry</source>
        <translation>Přidat novou položku</translation>
    </message>
    <message>
        <source>View/Edit entry</source>
        <translation>Zobrazit/upravit položku</translation>
    </message>
    <message>
        <source>Delete entry</source>
        <translation>Smazat položku</translation>
    </message>
    <message>
        <source>Add new group</source>
        <translation>Přidat novou skupinu</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>Upravit skupinu</translation>
    </message>
    <message>
        <source>Delete group</source>
        <translation>Smazat skupinu</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>Uložit databázi jako</translation>
    </message>
    <message>
        <source>Change master key</source>
        <translation>Změnit hlavní klíč</translation>
    </message>
    <message>
        <source>Database settings</source>
        <translation>Nastavení databáze</translation>
    </message>
    <message>
        <source>Import KeePass 1 database</source>
        <translation>Importovat databázi aplikace KeePass verze 1</translation>
    </message>
    <message>
        <source>Clone entry</source>
        <translation>Klonovat položku</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Najít</translation>
    </message>
    <message>
        <source>Copy username to clipboard</source>
        <translation>Zkopírovat uživatelské jméno do schránky</translation>
    </message>
    <message>
        <source>Copy password to clipboard</source>
        <translation>Zkopírovat heslo do schránky</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Perform Auto-Type</source>
        <translation>Provést automatické vyplnění</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation>Otevřít URL adresu</translation>
    </message>
    <message>
        <source>Lock databases</source>
        <translation>Uzamknout databáze</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titulek</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL adresa</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>Poznámky</translation>
    </message>
    <message>
        <source>Show toolbar</source>
        <translation>Zobrazit lištu nástrojů</translation>
    </message>
    <message>
        <source>read-only</source>
        <translation>pouze pro čtení</translation>
    </message>
    <message>
        <source>Toggle window</source>
        <translation>Zobrazit/skrýt okno</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Nástroje</translation>
    </message>
    <message>
        <source>Copy username</source>
        <translation>Zkopírovat uživatelské jméno</translation>
    </message>
    <message>
        <source>Copy password</source>
        <translation>Zkopírovat heslo</translation>
    </message>
    <message>
        <source>Export to CSV file</source>
        <translation>Exportovat do CSV souboru</translation>
    </message>
    <message>
        <source>Repair database</source>
        <translation>Opravit databázi</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>Databáze ve formátu KeePass 2</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Všechny soubory</translation>
    </message>
    <message>
        <source>Save repaired database</source>
        <translation>Uložit opravenou databázi</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>Zápis do databáze se nezdařil.</translation>
    </message>
</context>
<context>
    <name>PasswordGeneratorWidget</name>
    <message>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Délka:</translation>
    </message>
    <message>
        <source>Character Types</source>
        <translation>Typy znaků</translation>
    </message>
    <message>
        <source>Upper Case Letters</source>
        <translation>Velká písmena</translation>
    </message>
    <message>
        <source>Lower Case Letters</source>
        <translation>Malá písmena</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>Číslice</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>Zvláštní znaky</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>Vynechat podobně vypadající znaky (předejití záměně)</translation>
    </message>
    <message>
        <source>Ensure that the password contains characters from every group</source>
        <translation>Zajistit, aby heslo obsahovalo znaky ze všech zvolených skupin znaků</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Přijmout</translation>
    </message>
</context>
<context>
    <name>QCommandLineParser</name>
    <message>
        <source>Displays version information.</source>
        <translation>Zobrazí informace o verzi.</translation>
    </message>
    <message>
        <source>Displays this help.</source>
        <translation>Zobrazí tuto nápovědu.</translation>
    </message>
    <message>
        <source>Unknown option &apos;%1&apos;.</source>
        <translation>Neznámá předvolba %1.</translation>
    </message>
    <message>
        <source>Unknown options: %1.</source>
        <translation>Neznámé předvolby: %1.</translation>
    </message>
    <message>
        <source>Missing value after &apos;%1&apos;.</source>
        <translation>Chybějící hodnota, následující za %1.</translation>
    </message>
    <message>
        <source>Unexpected value after &apos;%1&apos;.</source>
        <translation>Neočekávaná hodnota, následující za %1.</translation>
    </message>
    <message>
        <source>[options]</source>
        <translation>[předvolby]</translation>
    </message>
    <message>
        <source>Usage: %1</source>
        <translation>Použití: %1</translation>
    </message>
    <message>
        <source>Options:</source>
        <translation>Předvolby:</translation>
    </message>
    <message>
        <source>Arguments:</source>
        <translation>Argumenty:</translation>
    </message>
</context>
<context>
    <name>QSaveFile</name>
    <message>
        <source>Existing file %1 is not writable</source>
        <translation>Do stávajícího souboru %1 nelze zapisovat</translation>
    </message>
    <message>
        <source>Writing canceled by application</source>
        <translation>Zápis byl zrušen aplikací</translation>
    </message>
    <message>
        <source>Partial write. Partition full?</source>
        <translation>Zápis nebylo možné zcela dokončit. Nedostatek volného místa?</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor</name>
    <message>
        <source>Internal zlib error when compressing: </source>
        <translation>Během komprimace se vyskytla vnitřní chyba v knihovně zlib:</translation>
    </message>
    <message>
        <source>Error writing to underlying device: </source>
        <translation>Došlo k chybě při zápisu na zařízení, na kterém se nachází:</translation>
    </message>
    <message>
        <source>Error opening underlying device: </source>
        <translation>Došlo k chybě při otevírání zařízení, na kterém se nachází:</translation>
    </message>
    <message>
        <source>Error reading data from underlying device: </source>
        <translation>Došlo k chybě při čtení dat ze zařízení, na kterém se nachází:</translation>
    </message>
    <message>
        <source>Internal zlib error when decompressing: </source>
        <translation>Vnitřní chyba knihovny zlib při rozbalování:</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor::open</name>
    <message>
        <source>The gzip format not supported in this version of zlib.</source>
        <translation>Použitý formát gzip komprese není podporován verzí knihovny zlib, která je právě používána na tomto systému.</translation>
    </message>
    <message>
        <source>Internal zlib error: </source>
        <translation>Vnitřní chyba knihovny zlib:</translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <source>Find:</source>
        <translation>Najít:</translation>
    </message>
    <message>
        <source>Case sensitive</source>
        <translation>Rozlišovat malá/velká písmena</translation>
    </message>
    <message>
        <source>Current group</source>
        <translation>Stávající skupina</translation>
    </message>
    <message>
        <source>Root group</source>
        <translation>Kořenová skupina</translation>
    </message>
</context>
<context>
    <name>SettingsWidget</name>
    <message>
        <source>Application Settings</source>
        <translation>Nastavení aplikace</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Zabezpečení</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetGeneral</name>
    <message>
        <source>Remember last databases</source>
        <translation>Pamatovat si nedávno otevřené databáze</translation>
    </message>
    <message>
        <source>Open previous databases on startup</source>
        <translation>Při spuštění aplikace otevřít minule otevřené databáze</translation>
    </message>
    <message>
        <source>Automatically save on exit</source>
        <translation>Před ukončením aplikace automaticky uložit případné změny</translation>
    </message>
    <message>
        <source>Automatically save after every change</source>
        <translation>Po každé změně hned automaticky uložit</translation>
    </message>
    <message>
        <source>Minimize when copying to clipboard</source>
        <translation>Po zkopírování údaje do schránky automaticky minimalizovat okno KeePassX (do popředí se tak dostane okno, do kterého se zkopírovaný údaj bude vkládat)</translation>
    </message>
    <message>
        <source>Use group icon on entry creation</source>
        <translation>Pro vytvářenou položku použít ikonu skupiny, do které spadá</translation>
    </message>
    <message>
        <source>Global Auto-Type shortcut</source>
        <translation>Klávesová zkratka pro všeobecné automatické vyplňování</translation>
    </message>
    <message>
        <source>Use entry title to match windows for global auto-type</source>
        <translation>Všeobecné automatické vyplňování provádět na základě shody titulku položky s titulkem okna.</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Jazyk</translation>
    </message>
    <message>
        <source>Show a system tray icon</source>
        <translation>Zobrazovat ikonu v oznamovací oblasti systémového panelu</translation>
    </message>
    <message>
        <source>Hide window to system tray when minimized</source>
        <translation>Minimalizovat okno aplikace do oznamovací oblasti systémového panelu</translation>
    </message>
    <message>
        <source>Remember last key files</source>
        <translation>Pamatovat si nedávno otevřené soubory s klíči</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetSecurity</name>
    <message>
        <source>Clear clipboard after</source>
        <translation>Vymazat obsah schránky po uplynutí</translation>
    </message>
    <message>
        <source> sec</source>
        <translation>sek.</translation>
    </message>
    <message>
        <source>Lock databases after inactivity of</source>
        <translation>Uzamknout databázi při nečinnosti delší než</translation>
    </message>
    <message>
        <source>Show passwords in cleartext by default</source>
        <translation>Hesla vždy viditelná (nezakrývat hvězdičkami)</translation>
    </message>
    <message>
        <source>Always ask before performing auto-type</source>
        <translation>Před provedením automatického vyplnění se vždy dotázat</translation>
    </message>
</context>
<context>
    <name>UnlockDatabaseWidget</name>
    <message>
        <source>Unlock database</source>
        <translation>Odemknout databázi</translation>
    </message>
</context>
<context>
    <name>WelcomeWidget</name>
    <message>
        <source>Welcome!</source>
        <translation>Vítejte!</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>KeePassX - cross-platform password manager</source>
        <translation>KeePassX – správce hesel, fungující napříč rozličnými operačními systémy</translation>
    </message>
    <message>
        <source>filename of the password database to open (*.kdbx)</source>
        <translation>který soubor s databází hesel (*.kdbx) otevřít</translation>
    </message>
    <message>
        <source>path to a custom config file</source>
        <translation>umístění souboru s vlastními nastaveními</translation>
    </message>
    <message>
        <source>key file of the database</source>
        <translation>soubor s klíčem k databázi</translation>
    </message>
</context>
</TS>